// 对Date的扩展，将 Date 转化为指定格式的String
// 月(M)、日(d)、小时(h)、分(m)、秒(s)、季度(q) 可以用 1-2 个占位符，
// 年(y)可以用 1-4 个占位符，毫秒(S)只能用 1 个占位符(是 1-3 位的数字)
// 例子：
// (new Date()).Format("yyyy-MM-dd hh:mm:ss.S") ==> 2006-07-02 08:09:04.423
// (new Date()).Format("yyyy-M-d h:m:s.S")      ==> 2006-7-2 8:9:4.18
Date.prototype.Format = function(fmt) { //author: meizz
	var o = {
		"M+": this.getMonth() + 1, //月份
		"d+": this.getDate(), //日
		"h+": this.getHours(), //小时
		"m+": this.getMinutes(), //分
		"s+": this.getSeconds(), //秒
		"q+": Math.floor((this.getMonth() + 3) / 3), //季度
		"S": this.getMilliseconds() //毫秒
	};
	if (/(y+)/.test(fmt))
		fmt = fmt.replace(RegExp.$1, (this.getFullYear() + "").substr(4 - RegExp.$1.length));
	for (var k in o)
		if (new RegExp("(" + k + ")").test(fmt))
			fmt = fmt.replace(RegExp.$1, (RegExp.$1.length == 1) ? (o[k]) : (("00" + o[k]).substr(("" + o[k])
				.length)));
	return fmt;
};
export default {
	// 时间格式化 2020-06-04T14:57:01 =>2020-06-04 14:57:01
	dateNormal: function(time) {
		return new Date(time).toISOString().replace(/T/g, ' ').replace(/\.[\d]{3}Z/, '')
	},

	dateFormat: function(timeSpan, fmt) {
		if (/^\d+$/.test(timeSpan)) {
			// 是纯数字
			return new Date(timeSpan).Format(fmt);
		} else {
			//timeSpan是待转换时间字符串，格式：'2018-9-12 9:11:23'
			let dateTmp = timeSpan.replace(/-/g, '/') //为了兼容IOS，需先将字符串转换为'2018/9/11 9:11:23'
			timeSpan = Date.parse(dateTmp) //返回时间戳
			return new Date(timeSpan).Format(fmt);
		}
	},

	// 时间格式转时间戳
	timeStampFromDateStr: function(dateStr) {
		return new Date(dateStr.replace(/-/g, '/')).getTime();
	},


	// 倒计时秒数转化为显示的分钟
	getEndTimeFormat: function(timeSpan, type = 0) {
		if (timeSpan <= 0)
			return "已结束";

		timeSpan = parseInt(timeSpan / 1000);
		var hours = parseInt(timeSpan / 3600);
		var hoursStr = hours.toString();
		var minutes = parseInt(timeSpan / 60) % 60;
		var minStr = minutes.toString();
		var second = timeSpan % 60;
		var secStr = second.toString();
		var timeStr = "";
		switch (type) {
			case 0:
				if (hoursStr > 0) {
					timeStr += hoursStr + '时';
				}
				timeStr += minStr + '分' + secStr + '秒';
				break;
			case 1:
				if (minStr > 0) {
					timeStr += minStr + '′';
				}
				timeStr += secStr + '″';
				break;
			case 2:
				const t2 = [hours, minutes, second].map(this.formatNumber).join(':')
				timeStr += t2;
			default:
				break;
		}
		return timeStr;
	},
	// 时间统一函数
	getChatTimeFormat: function(argument) {
		var times = new Date(argument);
		var timeS = new Date(argument).Format('yyyy/MM/dd hh:mm:ss');
		var todayT = '';
		var yestodayT = '';
		var timeCha = new Date().getTime() - new Date(times).getTime() - 1000; //有一秒的误差;
		timeS = timeS.slice(-8);
		todayT = new Date().getHours() * 60 * 60 * 1000 + new Date().getMinutes() * 60 * 1000 + new Date()
			.getSeconds() *
			1000;
		yestodayT = todayT + 24 * 60 * 60 * 1000;
		if (timeCha > yestodayT) {
			return new Date(argument).Format('yyyy年MM月dd日 hh:mm:ss');
		}
		if (timeCha > todayT && timeCha < yestodayT) {
			return timeS.slice(0, 2) > 12 ? '昨天 下午' + (timeS.slice(0, 2) == 12 ? 12 : timeS.slice(0, 2) - 12) +
				timeS.slice(2,
					5) : '昨天 上午' + timeS.slice(0, 5);
		}
		if (timeCha < todayT) {
			return timeS.slice(0, 2) >= 12 ? '下午' + (timeS.slice(0, 2) == 12 ? 12 : timeS.slice(0, 2) - 12) + timeS
				.slice(2, 5) :
				'上午' + timeS.slice(0, 5);
		}

	},
	//将一个时间戳转换成提示性时间字符串，如刚刚，1秒前
	convertTimeToFormat: function(timeStamp) {
		var time = (new Date().getTime() - timeStamp) / 1000;

		if (time < 60 * 2 && time >= -60) {
			return "刚刚";
		} else if (time >= 60 && time < 3600) {
			return Math.floor(time / 60) + "分钟前";
		} else if (time >= 3600 && time < 3600 * 24) {
			return Math.floor(time / 3600) + "小时前";
		} else if (time >= 3600 * 24 && time <= 3600 * 24 * 7) {
			return Math.floor(time / (3600 * 24)) + "天前";
		} else {
			return new Date(timeStamp).Format('yyyy.MM.dd');
		}
	},
	//处理接单助手、免费咨询列表的事件戳 将一个时间戳转换成提示性时间字符串，如刚刚，1秒前
	dealTimeToFreeList: function(timeStamp) {
		var time = (new Date().getTime() - timeStamp) / 1000;
		if (time < 60 * 2 && time >= -60) {
			return "刚刚";
		} else if (time >= 60 && time < 3600) {
			return Math.floor(time / 60) + "分钟前";
		} else if (this.isToday(timeStamp)) {
			return new Date(timeStamp).Format('hh:mm');
		} else if (this.isYesterday(timeStamp)) {
			return "昨天 " + new Date(timeStamp).Format('hh:mm');
		} else {
			return new Date(timeStamp).Format('yyyy-MM-dd');
		}
	},
	// N＜59分钟，则展示N分钟前
	// 1小时≤N≤24小时，则展示N/60 小时前
	// N＞24小时，则展示MM月DD日，如10月11日
	// 若咨询跨年，则展示YYYY年MM月DD日，如2021年12月12日
	convertTimeFormat: function(timeStamp) {
		var time = (new Date().getTime() - timeStamp) / 1000;
		if (time < 60 * 2 && time >= -60) {
			return "刚刚";
		} else if (time >= 60 && time < 3600) {
			return Math.floor(time / 60) + "分钟前";
		} else if (time >= 3600 && time < 3600 * 24) {
			return Math.floor(time / 3600) + "小时前";
		} else {
			if (new Date(timeStamp).getFullYear() == new Date().getFullYear()) {
				return new Date(timeStamp).Format('MM月dd日');
			} else {
				return new Date(timeStamp).Format('yyyy年MM月dd日');
			}

		}
	},
	//音频用时分秒转换00:00:00
	convertTime(time) {
		var resultTime = "";
		if (time >= 60 * 60) {
			resultTime = "" + Math.floor(time / 60 / 60) + ":";
			time = time % (60 * 60);
		}
		if (time >= 60) {
			if (time < 10 * 60) {
				resultTime = resultTime + "0" + Math.floor(time / 60) + ":"
			} else {
				resultTime = resultTime + Math.floor(time / 60) + ":"
			}
			time = time % 60
		} else {
			resultTime = resultTime + "00:"
		}
		if (time > 0) {
			if (time < 10) {
				resultTime = resultTime + "0" + time;
			} else {
				resultTime = resultTime + "" + time;
			}
		} else {
			resultTime = resultTime + "00"
		}
		return resultTime;
	},
	formatNumber: function(n) {
		const str = n.toString()
		return str[1] ? str : `0${str}`
	},
	//是否为今天
	isToday: function(time) {
		var d0 = new Date();
		var y0 = d0.getFullYear();
		var m0 = d0.getMonth() + 1;
		var d0 = d0.getDate();
		var d1 = new Date(time);
		var y1 = d1.getFullYear();
		var m1 = d1.getMonth() + 1;
		var d1 = d1.getDate();
		return y0 == y1 && m0 == m1 && d0 == d1;
	},
    //是否为昨天
	isYesterday: function(time) {
		var d0 = new Date();
		var y0 = d0.getFullYear();
		var m0 = d0.getMonth() + 1;
		var d0 = d0.getDate();
		var d1 = new Date(time);
		var y1 = d1.getFullYear();
		var m1 = d1.getMonth() + 1;
		var d1 = d1.getDate();
		return y0 == y1 && m0 == m1 && d0-1 == d1;
	},



}
